package erpordermanage

import (
	"encoding/json"
	"errors"
	"github.com/gin-gonic/gin"
	model "go-admin/app/admin/models"
	orm "go-admin/common/global"
	"go-admin/logger"
	"go-admin/tools"
	"go-admin/tools/app"
	"net/http"
	"time"
)

// ErpOrderCreate 新建零售订单
// @Summary 新建零售订单
// @Tags 零售订单
// @Produce json
// @Accept json
// @Param request body models.ErpOrderCreateReq true "新建零售订单模型"
// @Success 200 {object} app.Response
// @Router /api/v1/erp_order/create [post]
func ErpOrderCreate(c *gin.Context) {
	var req = new(model.ErpOrderCreateReq)
	if err := c.ShouldBindJSON(&req); err != nil {
		logger.Error("ShouldBindJSON err:", logger.Field("err", err))
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	err := tools.Validate(req) //必填参数校验
	if err != nil {
		app.Error(c, http.StatusBadRequest, err, err.Error())
		return
	}

	jCashier, err := json.Marshal(req.Cashiers)
	if err != nil {
		logger.Error("cashiers marshal err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	sysUser, err := model.GetSysUserByCtx(c)
	if err != nil {
		logger.Error("sys user err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	//if sysUser.StoreId == 0 {// 校验登陆账户所属门店
	//	logger.Error("sys user store id null")
	//	app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
	//	return
	//}

	erpOrder := &model.ErpOrder{
		BillSn:        model.NewErpBillSn(),
		RetailType:    req.RetailType,
		Uid:           sysUser.UserId,
		Tel:           req.Tel,
		StoreId:       sysUser.StoreId,
		StoreName:     sysUser.StoreName,
		MakerId:       uint32(sysUser.UserId),
		MakerName:     sysUser.NickName,
		MakerTime:     time.Now(),
		CashierList:   string(jCashier),
		Salesman1:     req.Salesman1,
		SalesmanName1: req.SalesmanName1,
		Salesman2:     req.Salesman2,
		SalesmanName2: req.SalesmanName2,
		MemberType:    req.MemberType,
		State:         model.ErpOrderStateUnAudit,
		PayStatus:     model.NoCreatePayOrder,
		IsPrint:       model.NoPrint, // 未打印
		PrintCount:    0,             // 打印次数
	}

	commodityMap := make(map[uint32]model.ErpCommodity)
	if req.RetailType == model.RetailTypeSale { // 零售订单，查商品表信息
		commodityIds := make([]uint32, 0, len(req.ErpOrderCommodities))
		for i, _ := range req.ErpOrderCommodities {
			commodityIds = append(commodityIds, req.ErpOrderCommodities[i].ErpCommodityId)
		}
		var commodities []model.ErpCommodity
		err = orm.Eloquent.Table("erp_commodity").Where("id IN (?)", commodityIds).Find(&commodities).Error
		if err != nil {
			logger.Error("commodities err:", logger.Field("err", err))
			app.Error(c, http.StatusInternalServerError, err, "操作失败")
			return
		}

		for i, _ := range commodities {
			commodityMap[commodities[i].ID] = commodities[i]
		}

		// 更新用户信息表，添加首次零售订单时间
		model.SetUserInfo(req.Tel)
	}

	var orderCommodityMap map[uint32]model.ErpOrderCommodity
	if req.RetailType == model.RetailTypeRejected { // 零售退货订单，查零售商品表
		ids := make([]uint32, 0, len(req.ErpOrderCommodities))
		for i, _ := range req.ErpOrderCommodities {
			ids = append(ids, req.ErpOrderCommodities[i].RejectedOrderCommodityId)
		}
		orderCommodityMap, err = model.GetErpOrderCommodityMap(ids)
		if err != nil {
			logger.Error("order commodity map err:", logger.Field("err", err))
			return
		}
	}

	// 校验商品相关金额是否符合要求
	for i, _ := range req.ErpOrderCommodities {
		if req.RetailType == model.RetailTypeRejected { // 零售退货订单
			v, ok := orderCommodityMap[req.ErpOrderCommodities[i].RejectedOrderCommodityId]
			if ok {
				v.RejectedPrice = req.ErpOrderCommodities[i].RejectedPrice // 退货单价
				v.RejectedCount = req.ErpOrderCommodities[i].RejectedCount
				v.RejectedAmount = float64(v.RejectedCount) * v.RejectedPrice
			} else {
				logger.Error("rejected order commodity id is null")
				return
			}
			v.ID = 0
			req.ErpOrderCommodities[i] = v
			if req.ErpOrderCommodities[i].RejectedPrice > req.ErpOrderCommodities[i].Amount { // 退货单价不能大于实际零售价
				logger.Error("rejected price gt retail price ")
				app.Error(c, http.StatusInternalServerError, err, "退货单价大于实际零售价")
				return
			}
			if req.ErpOrderCommodities[i].RejectedCount > req.ErpOrderCommodities[i].Count { // 退货数量不能大于销售数量
				logger.Error("rejected count gt retail count ")
				app.Error(c, http.StatusInternalServerError, err, "退货数量大于销售数量")
				return
			}

			// 更新订单表总金额和数量
			erpOrder.TotalAmount += req.ErpOrderCommodities[i].Amount
			erpOrder.TotalCount += req.ErpOrderCommodities[i].Count

		} else if req.RetailType == model.RetailTypeSale { // 零售订单
			v, ok := commodityMap[req.ErpOrderCommodities[i].ErpCommodityId]
			if ok {
				req.ErpOrderCommodities[i].ID = 0
				req.ErpOrderCommodities[i].ErpCommodityId = v.ID               // 商品id
				req.ErpOrderCommodities[i].ErpCommodityName = v.Name           // 商品名称
				req.ErpOrderCommodities[i].ErpCategoryId = v.ErpCategoryId     // 分类id
				req.ErpOrderCommodities[i].ErpCategoryName = v.ErpCategoryName // 分类名称
				req.ErpOrderCommodities[i].RetailPrice = v.RetailPrice         // 指导零售价
				req.ErpOrderCommodities[i].MemberDiscount = v.MemberDiscount   // 会员优惠
			}

			if req.ErpOrderCommodities[i].PresentType == 2 && v.MinRetailPrice != 0 { // 赠送类型商品进行校验，最低零售价为0才能赠送
				logger.Error("PresentType is 2, MinRetailPrice no equal 0")
				app.Error(c, http.StatusInternalServerError, err, "赠送商品最低零售价不为0，不符合赠送条件，请检查")
				return
			}

			if req.ErpOrderCommodities[i].SalePrice < v.MinRetailPrice { //零售价不能低于最低零售价
				logger.Error("SalePrice less than MinRetailPrice")
				app.Error(c, http.StatusInternalServerError, err, "零售价不能低于最低零售价，请检查")
				return
			}

			// 更新订单表总退款金额和数量
			erpOrder.TotalAmount += req.ErpOrderCommodities[i].RejectedAmount
			erpOrder.TotalCount += req.ErpOrderCommodities[i].RejectedCount
		}
	}

	begin := orm.Eloquent.Begin()
	err = begin.Create(erpOrder).Error // 创建零售订单
	if err != nil {
		begin.Rollback()
		logger.Error("create erp order err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	// 订单商品表信息添加零售订单id
	for i, _ := range req.ErpOrderCommodities {
		req.ErpOrderCommodities[i].ErpOrderId = erpOrder.ID
	}

	// 创建商品订单信息
	err = begin.Create(&req.ErpOrderCommodities).Error
	if err != nil {
		begin.Rollback()
		logger.Error("Create")
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	err = begin.Commit().Error
	if err != nil {
		begin.Rollback()
		logger.Error("commit err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	app.OK(c, nil, "")
	return
}

// ErpOrderEdit 编辑零售订单
// @Summary 编辑零售订单
// @Tags 零售订单
// @Produce json
// @Accept json
// @Param request body models.ErpOrderCreateReq true "编辑零售订单模型"
// @Success 200 {object} app.Response
// @Router /api/v1/erp_order/edit [post]
func ErpOrderEdit(c *gin.Context) {
	var req = new(model.ErpOrderCreateReq)
	if err := c.ShouldBindJSON(&req); err != nil {
		logger.Error("ShouldBindJSON err:", logger.Field("err", err))
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	err := tools.Validate(req) //必填参数校验
	if err != nil {
		app.Error(c, http.StatusBadRequest, err, err.Error())
		return
	}

	jCashier, err := json.Marshal(req.Cashiers)
	if err != nil {
		logger.Error("cashiers marshal err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	sysUser, err := model.GetSysUserByCtx(c)
	if err != nil {
		logger.Error("sys user err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	var orderInfo model.ErpOrder
	err = orm.Eloquent.Table("erp_order").Where("bill_sn=?", req.BillSn).Find(&orderInfo).Error
	if err != nil {
		logger.Error("GetOrderState err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	if orderInfo.State != "ErpOrderStateUnAudit" {
		logger.Error("GetOrderState err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "订单状态不是待审核，操作失败")
		return
	}

	//if sysUser.StoreId == 0 {// 校验登陆账户所属门店
	//	logger.Error("sys user store id null")
	//	app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
	//	return
	//}

	erpOrder := &model.ErpOrder{
		BillSn:        req.BillSn,
		RetailType:    req.RetailType,
		Uid:           sysUser.UserId,
		Tel:           req.Tel,
		StoreId:       sysUser.StoreId,
		StoreName:     sysUser.StoreName,
		MakerId:       uint32(sysUser.UserId),
		MakerName:     sysUser.NickName,
		MakerTime:     time.Now(),
		CashierList:   string(jCashier),
		Salesman1:     req.Salesman1,
		SalesmanName1: req.SalesmanName1,
		Salesman2:     req.Salesman2,
		SalesmanName2: req.SalesmanName2,
		MemberType:    req.MemberType,
		State:         model.ErpOrderStateUnAudit,
		PayStatus:     model.NoCreatePayOrder,
		IsPrint:       model.NoPrint, // 未打印
		PrintCount:    0,             // 打印次数
	}
	erpOrder.ID = orderInfo.ID

	commodityMap := make(map[uint32]model.ErpCommodity)
	if req.RetailType == model.RetailTypeSale { // 零售订单，查商品表信息
		commodityIds := make([]uint32, 0, len(req.ErpOrderCommodities))
		for i, _ := range req.ErpOrderCommodities {
			commodityIds = append(commodityIds, req.ErpOrderCommodities[i].ErpCommodityId)
		}
		var commodities []model.ErpCommodity
		err = orm.Eloquent.Table("erp_commodity").Where("id IN (?)", commodityIds).Find(&commodities).Error
		if err != nil {
			logger.Error("commodities err:", logger.Field("err", err))
			app.Error(c, http.StatusInternalServerError, err, "操作失败")
			return
		}

		for i, _ := range commodities {
			commodityMap[commodities[i].ID] = commodities[i]
		}

		// 更新用户信息表，添加首次零售订单时间
		model.SetUserInfo(req.Tel)
	}

	var orderCommodityMap map[uint32]model.ErpOrderCommodity
	if req.RetailType == model.RetailTypeRejected { // 零售退货订单，查零售商品表
		ids := make([]uint32, 0, len(req.ErpOrderCommodities))
		for i, _ := range req.ErpOrderCommodities {
			ids = append(ids, req.ErpOrderCommodities[i].RejectedOrderCommodityId)
		}
		orderCommodityMap, err = model.GetErpOrderCommodityMap(ids)
		if err != nil {
			logger.Error("order commodity map err:", logger.Field("err", err))
			return
		}
	}

	// 校验商品相关金额是否符合要求
	for i, _ := range req.ErpOrderCommodities {
		if req.RetailType == model.RetailTypeRejected { // 零售退货订单
			v, ok := orderCommodityMap[req.ErpOrderCommodities[i].RejectedOrderCommodityId]
			if ok {
				v.RejectedPrice = req.ErpOrderCommodities[i].RejectedPrice // 退货单价
				v.RejectedCount = req.ErpOrderCommodities[i].RejectedCount
				v.RejectedAmount = float64(v.RejectedCount) * v.RejectedPrice
			} else {
				logger.Error("rejected order commodity id is null")
				return
			}
			v.ID = 0
			req.ErpOrderCommodities[i] = v
			if req.ErpOrderCommodities[i].RejectedPrice > req.ErpOrderCommodities[i].Amount { // 退货单价不能大于实际零售价
				logger.Error("rejected price gt retail price ")
				app.Error(c, http.StatusInternalServerError, err, "退货单价大于实际零售价")
				return
			}
			if req.ErpOrderCommodities[i].RejectedCount > req.ErpOrderCommodities[i].Count { // 退货数量不能大于销售数量
				logger.Error("rejected count gt retail count ")
				app.Error(c, http.StatusInternalServerError, err, "退货数量大于销售数量")
				return
			}

			// 更新订单表总金额和数量
			erpOrder.TotalAmount += req.ErpOrderCommodities[i].Amount
			erpOrder.TotalCount += req.ErpOrderCommodities[i].Count

		} else if req.RetailType == model.RetailTypeSale { // 零售订单
			v, ok := commodityMap[req.ErpOrderCommodities[i].ErpCommodityId]
			if ok {
				req.ErpOrderCommodities[i].ErpCommodityId = v.ID               // 商品id
				req.ErpOrderCommodities[i].ErpCommodityName = v.Name           // 商品名称
				req.ErpOrderCommodities[i].ErpCategoryId = v.ErpCategoryId     // 分类id
				req.ErpOrderCommodities[i].ErpCategoryName = v.ErpCategoryName // 分类名称
				req.ErpOrderCommodities[i].RetailPrice = v.RetailPrice         // 指导零售价
				req.ErpOrderCommodities[i].MemberDiscount = v.MemberDiscount   // 会员优惠
			}

			if req.ErpOrderCommodities[i].PresentType == 2 && v.MinRetailPrice != 0 { // 赠送类型商品进行校验，最低零售价为0才能赠送
				logger.Error("PresentType is 2, MinRetailPrice no equal 0")
				app.Error(c, http.StatusInternalServerError, err, "赠送商品最低零售价不为0，不符合赠送条件，请检查")
				return
			}

			if req.ErpOrderCommodities[i].SalePrice < v.MinRetailPrice { //零售价不能低于最低零售价
				logger.Error("SalePrice less than MinRetailPrice")
				app.Error(c, http.StatusInternalServerError, err, "零售价不能低于最低零售价，请检查")
				return
			}

			// 更新订单表总退款金额和数量
			erpOrder.TotalAmount += req.ErpOrderCommodities[i].RejectedAmount
			erpOrder.TotalCount += req.ErpOrderCommodities[i].RejectedCount
		}
	}

	begin := orm.Eloquent.Begin()
	err = begin.Updates(erpOrder).Error // 更新零售订单
	if err != nil {
		begin.Rollback()
		logger.Error("create erp order err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	// 订单商品表信息添加零售订单id
	for i, _ := range req.ErpOrderCommodities {
		req.ErpOrderCommodities[i].ErpOrderId = erpOrder.ID
	}

	// 创建商品订单信息
	err = begin.Updates(&req.ErpOrderCommodities).Error
	if err != nil {
		begin.Rollback()
		logger.Error("Create")
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	err = begin.Commit().Error
	if err != nil {
		begin.Rollback()
		logger.Error("commit err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	app.OK(c, nil, "")
	return
}

// ErpOrderList 查询零售订单列表
// @Summary 查询零售订单列表
// @Tags 零售订单
// @Produce json
// @Accept json
// @Param request body models.ErpOrderListReq true "查询零售订单列表模型"
// @Success 200 {object} models.ErpOrderListResp
// @Router /api/v1/erp_order/list [post]
func ErpOrderList(c *gin.Context) {
	req := &model.ErpOrderListReq{}
	if err := c.ShouldBindJSON(&req); err != nil {
		logger.Error("ShouldBindJSON err:", logger.Field("err", err))
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	resp, err := req.List()
	if err != nil {
		logger.Error("erp commodity list err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "获取失败")
		return
	}

	app.OK(c, resp, "")
	return
}

// ErpOrderAudit 审核零售订单（审核、取消审核）
// @Summary 审核零售订单
// @Tags 零售订单
// @Produce json
// @Accept json
// @Param request body models.ErpOrderAuditReq true "审核零售订单模型"
// @Success 200 {object} app.Response
// @Router /api/v1/erp_order/audit [post]
func ErpOrderAudit(c *gin.Context) {
	var req = new(model.ErpOrderAuditReq)
	if err := c.ShouldBindJSON(&req); err != nil {
		logger.Error("ShouldBindJSON err:", logger.Field("err", err))
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	err := tools.Validate(req) //必填参数校验
	if err != nil {
		app.Error(c, http.StatusBadRequest, err, err.Error())
		return
	}
	var erpOrder model.ErpOrder
	err = orm.Eloquent.Table("erp_order").Where("bill_sn = ?", req.BillSn).Find(&erpOrder).Error
	if err != nil {
		logger.Error("order err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "审核失败")
		return
	}

	orderState := model.ErpOrderStateAudited
	switch req.State {
	case 1: // 审核
		orderState = model.ErpOrderStateAudited
	case 2: // 取消审核
		orderState = model.ErpOrderStateUnAudit
	default:
		logger.Error("req.State no in (1,2)", logger.Field("req.State", req.State))
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	// 检查支付方式，如果没有线上支付则默认为支付已完成
	nPayStatus := model.WaitForPaying // 待支付
	var cashiers []model.ErpOrderCashier
	err = json.Unmarshal([]byte(erpOrder.CashierList), &cashiers)
	if err != nil {
		logger.Error("unmarshal CashierList err:", logger.Field("err", err))
	}
	if !model.CheckIsOnlinePay(cashiers) {
		nPayStatus = model.HavePaid // 已完成
	}

	begin := orm.Eloquent.Begin()
	err = begin.Table("erp_order").Where("id = ?", erpOrder.ID).Updates(map[string]interface{}{
		"state":      orderState,
		"pay_status": nPayStatus,
		"audit_time": time.Now(),
	}).Error
	if err != nil {
		begin.Rollback()
		logger.Error("order err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "审核失败")
		return
	}

	// 更新库存
	err = model.UpdateStock(begin, erpOrder)
	if err != nil {
		begin.Rollback()
		logger.Error("UpdateStock err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "审核失败")
		return
	}

	err = begin.Commit().Error
	if err != nil {
		begin.Rollback()
		logger.Error("UpdateStock err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "删除失败")
		return
	}

	app.OK(c, nil, "")
	return
}

// ErpOrderDelete 删除零售订单
// @Summary 删除零售订单
// @Tags 零售订单
// @Produce json
// @Accept json
// @Param request body models.ErpOrderDeleteReq true "删除零售订单模型"
// @Success 200 {object} app.Response
// @Router /api/v1/erp_order/delete [post]
func ErpOrderDelete(c *gin.Context) {
	var req = new(model.ErpOrderDeleteReq)
	if err := c.ShouldBindJSON(&req); err != nil {
		logger.Error("ShouldBindJSON err:", logger.Field("err", err))
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	err := tools.Validate(req) //必填参数校验
	if err != nil {
		app.Error(c, http.StatusBadRequest, err, err.Error())
		return
	}

	err = model.DeleteOrder(req)
	if err != nil {
		logger.Error("AddInvoice err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	app.OK(c, nil, "")
	return
}

// ErpOrderAddInvoice 开发票
// @Summary 开发票
// @Tags 零售订单
// @Produce json
// @Accept json
// @Param request body models.ErpOrderAddInvoiceReq true "开发票模型"
// @Success 200 {object} app.Response
// @Router /api/v1/erp_order/add_invoice [post]
func ErpOrderAddInvoice(c *gin.Context) {
	var req = new(model.ErpOrderAddInvoiceReq)
	if err := c.ShouldBindJSON(&req); err != nil {
		logger.Error("ShouldBindJSON err:", logger.Field("err", err))
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	err := tools.Validate(req) //必填参数校验
	if err != nil {
		app.Error(c, http.StatusBadRequest, err, err.Error())
		return
	}

	err = model.SetInvoice(req)
	if err != nil {
		logger.Error("AddInvoice err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "操作失败")
		return
	}

	app.OK(c, nil, "")
	return
}

// ErpOrderPay 收款
// @Summary 收款
// @Tags 零售订单
// @Produce json
// @Accept json
// @Param request body models.ErpOrderPayReq true "收款模型"
// @Success 200 {object} models.ErpOrderPayResp
// @Router /api/v1/erp_order/pay [post]
func ErpOrderPay(c *gin.Context) {
	var req = new(model.ErpOrderPayReq)
	if err := c.ShouldBindJSON(&req); err != nil {
		logger.Error("ShouldBindJSON err:", logger.Field("err", err))
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	err := tools.Validate(req) //必填参数校验
	if err != nil {
		app.Error(c, http.StatusBadRequest, err, err.Error())
		return
	}

	resp, err := model.ErpOrderPay(req)
	if err != nil {
		logger.Error("ErpOrderPay err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, err.Error())
		return
	}

	app.OK(c, resp, "")
	return
}

// ErpOrderQueryPayStatus 查询付款状态
// @Summary 查询付款状态
// @Tags 零售订单
// @Produce json
// @Accept json
// @Param request body models.ErpOrderDeleteReq true "查询付款状态模型"
// @Success 200 {object} models.ErpOrderPayResp
// @Router /api/v1/erp_order/query_pay_status [post]
func ErpOrderQueryPayStatus(c *gin.Context) {
	var req = new(model.ErpOrderDeleteReq)
	if err := c.ShouldBindJSON(&req); err != nil {
		logger.Error("ShouldBindJSON err:", logger.Field("err", err))
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	err := tools.Validate(req) //必填参数校验
	if err != nil {
		app.Error(c, http.StatusBadRequest, err, err.Error())
		return
	}

	resp, err := model.QueryErpOrderPayStatus(req.BillSn)
	if err != nil {
		logger.Error("QueryErpOrderPayStatus err:", logger.Field("err", err))
		app.Error(c, http.StatusInternalServerError, err, "查询失败")
		return
	}

	app.OK(c, resp, "")
	return
}
